# lhub
Python package for interacting with LogicHub APIs

# Version History
### 0.0.8
* LogicHubAPI.get_batches_by_stream_id: Added support for a limit of -1 in order to set it to unlimited
* LogicHub.action_get_batches_by_stream_id: Set the default limit to unlimited
